Enum hyper::header::DispositionParam [−] [src]

pub enum DispositionParam {
    Filename(Charset, Option<LanguageTag>, Vec<u8>),
    Ext(String, String),
}

A parameter to the disposition type

Variants

A Filename consisting of a Charset, an optional LanguageTag, and finally a sequence of bytes representing the filename

Extension type consisting of token and value. Recipients should ignore unrecognized parameters.